@@ -27,7 +27,11 @@ def slice2d_custom_rotation(custom_rotation=None,
 
     # Transform particle and support vectors
     if vectors is not None:
-        vectors = matrix @ vectors
+        transformed = np.zeros(vectors.shape)
+        num_vectors = vectors.shape[0]
+        for vector_idx in range(num_vectors):
+            transformed[vector_idx] = matrix.T @ vectors[vector_idx, :]
+        vectors = transformed
     if vbulk is not None:
         vbulk = matrix @ vbulk
     if bfield is not None:
