@@ -1,7 +1,7 @@
 import os
 
 CONFIG = {'local_data_dir': 'psp_data/',
-          'remote_data_dir': 'https://spdf.sci.gsfc.nasa.gov/pub/data/psp/'}
+          'remote_data_dir': 'https://spdf.gsfc.nasa.gov/pub/data/psp/'}
 
 # override local data directory with environment variables
 if os.environ.get('SPEDAS_DATA_DIR'):
